diff --git a/app/Http/Controllers/ProductController.php b/app/Http/Controllers/ProductController.php
index 1765a9d..fd4e0db 100644
--- a/app/Http/Controllers/ProductController.php
+++ b/app/Http/Controllers/ProductController.php
@@ -4,7 +4,7 @@
use Illuminate\Http\Response;
use Lunar\Models\Collection;
-use Modules\Core\Catalog\ProductService;
+use Modules\Core\Product\Services\ProductService;
class ProductController extends Controller
{
diff --git a/config/lunar/search.php b/config/lunar/search.php
index a976277..324b572 100644
--- a/config/lunar/search.php
+++ b/config/lunar/search.php
@@ -49,7 +49,7 @@
Lunar\Models\Collection::class => Lunar\Search\CollectionIndexer::class,
Lunar\Models\Customer::class => Lunar\Search\CustomerIndexer::class,
Lunar\Models\Order::class => Lunar\Search\OrderIndexer::class,
- Lunar\Models\Product::class => Modules\Core\Search\ProductIndexer::class,
+ Lunar\Models\Product::class => Modules\Core\Product\Services\ProductIndexer::class,
Lunar\Models\ProductOption::class => Lunar\Search\ProductOptionIndexer::class,
],
diff --git a/lang/el/general.php b/lang/el/general.php
deleted file mode 100644
index f1e0ede..0000000
--- a/lang/el/general.php
+++ /dev/null
@@ -1,44 +0,0 @@
- [
- 'home' => 'Αρχική',
- 'products' => 'Προϊόντα',
- 'contact' => 'Επικοινωνία',
- ],
-
- 'product' => [
- 'description' => 'Περιγραφή',
- 'reviews' => 'Αξιολογήσεις',
- ],
-
- // Laravel pluralization: {0} zero|{1} one|[2,*] many. :count is replaced automatically.
- 'customer_reviews' => '{0} Καμία αξιολόγηση πελάτη|{1} :count αξιολόγηση πελάτη|[2,*] :count αξιολογήσεις πελατών',
-
- 'shop' => [
- // Laravel pluralization keyed on the total result count.
- 'showing_results' => '{0} Δεν βρέθηκαν προϊόντα|{1} Εμφάνιση :first–:last από :total αποτέλεσμα|[2,*] Εμφάνιση :first–:last από :total αποτελέσματα',
- 'no_products' => 'Δεν βρέθηκαν προϊόντα σε αυτή την κατηγορία.',
- 'search_label' => 'Αναζήτηση προϊόντων',
- 'search_placeholder' => 'Αναζήτησε προϊόντα…',
- 'filter_price' => 'Φίλτρο τιμής',
- 'apply' => 'Εφαρμογή',
- 'availability' => 'Διαθεσιμότητα',
- 'in_stock_only' => 'Μόνο διαθέσιμα προϊόντα',
- 'sort_label' => 'Ταξινόμηση προϊόντων',
- 'sort_default' => 'Προεπιλεγμένη ταξινόμηση',
- 'sort_popularity' => 'Δημοφιλή',
- 'sort_price_asc' => 'Τιμή: Αύξουσα',
- 'sort_price_desc' => 'Τιμή: Φθίνουσα',
- 'sort_newest' => 'Νεότερα',
- ],
-
- 'pagination' => [
- 'nav_label' => 'Σελιδοποίηση',
- 'page' => 'Σελίδα :page',
- 'next' => 'Επόμενη σελίδα',
- 'previous' => 'Προηγούμενη σελίδα',
- ],
-
-];
diff --git a/lang/en/general.php b/lang/en/general.php
deleted file mode 100644
index e94338e..0000000
--- a/lang/en/general.php
+++ /dev/null
@@ -1,44 +0,0 @@
- [
- 'home' => 'Home',
- 'products' => 'Products',
- 'contact' => 'Contact',
- ],
-
- 'product' => [
- 'description' => 'Description',
- 'reviews' => 'Reviews',
- ],
-
- // Laravel pluralization: {0} zero|{1} one|[2,*] many. :count is replaced automatically.
- 'customer_reviews' => '{0} No customer reviews|{1} :count customer review|[2,*] :count customer reviews',
-
- 'shop' => [
- // Laravel pluralization keyed on the total result count.
- 'showing_results' => '{0} No products found|{1} Showing :first–:last of :total result|[2,*] Showing :first–:last of :total results',
- 'no_products' => 'No products found in this category.',
- 'search_label' => 'Search products',
- 'search_placeholder' => 'Search products…',
- 'filter_price' => 'Filter by price',
- 'apply' => 'Apply',
- 'availability' => 'Availability',
- 'in_stock_only' => 'In-stock products only',
- 'sort_label' => 'Sort products',
- 'sort_default' => 'Default sorting',
- 'sort_popularity' => 'Popularity',
- 'sort_price_asc' => 'Price: Low to High',
- 'sort_price_desc' => 'Price: High to Low',
- 'sort_newest' => 'Newest',
- ],
-
- 'pagination' => [
- 'nav_label' => 'Pagination',
- 'page' => 'Page :page',
- 'next' => 'Next page',
- 'previous' => 'Previous page',
- ],
-
-];
diff --git a/resources/views/category/show.blade.php b/resources/views/category/show.blade.php
index 5b9fa56..06cf2cf 100644
--- a/resources/views/category/show.blade.php
+++ b/resources/views/category/show.blade.php
@@ -10,14 +10,14 @@
- {{ trans_choice('general.shop.showing_results', $products->total(), [
+ {{ trans_choice('storefront.shop.showing_results', $products->total(), [
'first' => $products->firstItem() ?? 0,
'last' => $products->lastItem() ?? 0,
'total' => $products->total(),
@@ -26,13 +26,13 @@
{{-- Dummy — not wired to real sorting yet --}}
@@ -43,7 +43,7 @@
{{-- Products --}}
@if($products->isEmpty())
-
{{ __('general.shop.no_products') }}
+
{{ __('storefront.shop.no_products') }}
@else
@@ -57,18 +57,18 @@
@@ -180,8 +180,8 @@ class="absolute bottom-6 right-8 text-white text-sm"
@@ -207,11 +207,12 @@ class="absolute bottom-6 right-8 text-white text-sm"
@endforeach
@else
- Δεν υπάρχουν αξιολογήσεις ακόμα.
+ {{ __('storefront.review.no_reviews_yet') }}
@endif
- {{ $product['review_count'] > 0 ? 'Πρόσθεσε μια' : 'Γράψε την πρώτη' }} αξιολόγηση για το «{{ $product['name'] }}»
+ {{ $product['review_count'] > 0 ? __('storefront.review.write_new') : __('storefront.review.write_first') }}
+ {{ __('storefront.review.for_product', ['name' => $product['name']]) }}
diff --git a/app/Http/Controllers/CategoryController.php b/app/Http/Controllers/CategoryController.php
index 87aa156..e6f8912 100644
--- a/app/Http/Controllers/CategoryController.php
+++ b/app/Http/Controllers/CategoryController.php
@@ -3,8 +3,8 @@
namespace App\Http\Controllers;
use Lunar\Models\Collection;
-use Modules\Core\Catalog\ProductFilters;
-use Modules\Core\Catalog\ProductService;
+use Modules\Core\Product\DTOs\ProductFilters;
+use Modules\Core\Product\Services\ProductService;
class CategoryController extends Controller
{
@@ -18,7 +18,7 @@ public function show(string $locale, Collection $collection)
$page = (int) request('page', 1);
// Listing/filtering reads from the Meilisearch index via ProductService,
// not Eloquent — see Modules\Core\Catalog\ProductService. list() returns a
// real LengthAwarePaginator of plain arrays (already localized/flattened),
// not Product models.
$products = $this->products->list(
@@ -18,7 +18,7 @@ public function show(string $locale, Collection $collection)
$page = (int) request('page', 1);
// Listing/filtering reads from the Meilisearch index via ProductService,
- // not Eloquent — see Modules\Core\Catalog\ProductService. list() returns a
+ // not Eloquent — see Modules\Core\Product\Services\ProductService. list() returns a
// real LengthAwarePaginator of plain arrays (already localized/flattened),
// not Product models.